@@ -1404,8 +1404,66 @@ class WinOSClient:
         result = self.run_ps_local(cmd)
         return result.ok
 
-    def get_volumes(self) -> list[dict]:
-        """Get virtual volumes info"""
+    def get_disks(self, dimension: str = None) -> list[dict]:
+        """Get Disks info
+
+        :param dimension: Bytes by default. MB (rounded) | GB (rounded)
+        """
+
+        dim = '' if dimension is None else dimension  # Just to shorten var name
+        converter = None
+
+        if dim.upper() == 'MB':
+            converter = self._convert_b_to_mb
+        elif dim.upper() == 'GB':
+            converter = self._convert_b_to_gb
+
+        disks = self.run_ps('Get-Disk | ConvertTo-Json').json()
+
+        result = [
+            {
+                'DiskNumber': disk['DiskNumber'],
+                'NumberOfPartitions': disk['NumberOfPartitions'],
+                'PartitionStyle': disk['PartitionStyle'],
+                'ProvisioningType': disk['ProvisioningType'],
+                'OperationalStatus': disk['OperationalStatus'],
+                'HealthStatus': disk['HealthStatus'],
+                'BusType': disk['BusType'],
+                'SerialNumber': disk['SerialNumber'],
+                'AllocatedSize': converter(disk['AllocatedSize']) if dim else disk['AllocatedSize'],
+                'BootFromDisk': disk['BootFromDisk'],
+                'IsBoot': disk['IsBoot'],
+                'IsClustered': disk['IsClustered'],
+                'IsOffline': disk['IsOffline'],
+                'IsReadOnly': disk['IsReadOnly'],
+                'Location': disk['Location'],
+                'LogicalSectorSize': disk['LogicalSectorSize'],
+                'PhysicalSectorSize': disk['PhysicalSectorSize'],
+                'Manufacturer': disk['Manufacturer'],
+                'Model': disk['Model'],
+                f'Size': converter(disk['Size']) if dim else disk['Size'],
+
+            } for disk in disks
+        ]
+
+        msg = f'NOTE: Size will be rounded up to integer ({dim}). {result}' if dim else result.__str__()
+        self.logger.info(msg)
+        return result
+
+    def get_volumes(self, dimension: str = None) -> list[dict]:
+        """Get virtual volumes info.
+
+        :param dimension: Bytes by default. MB (rounded) | GB (rounded)
+        :return:
+        """
+
+        dim = '' if dimension is None else dimension  # Just to shorten var name
+        conv = None
+
+        if dim.upper() == 'MB':
+            conv = self._convert_b_to_mb
+        elif dim.upper() == 'GB':
+            conv = self._convert_b_to_gb
 
         disks = self.run_ps('Get-Volume | ConvertTo-Json').json()
 
@@ -1413,8 +1471,9 @@ class WinOSClient:
             {
                 'DriveLetter': disk['DriveLetter'],
                 'FileSystemLabel': disk['FileSystemLabel'],
-                'Size': int(disk['Size']),
-                'SizeRemaining': int(disk['SizeRemaining']),
+                'Size': conv(disk['Size']) if dim else disk['Size'],
+                'SizeRemaining': conv(disk['SizeRemaining']) if dim else disk['SizeRemaining'],
+                'SizeUsed': conv(disk['Size'] - disk['SizeRemaining']) if dim else disk['Size'] - disk['SizeRemaining'],
                 'HealthStatus': disk['HealthStatus'],
                 'DriveType': disk['DriveType'],
                 'FileSystem': disk['FileSystem'],
@@ -1426,17 +1485,37 @@ class WinOSClient:
             } for disk in disks
         ]
 
+        msg = f'NOTE: Size will be rounded up to integer ({dim}). {result}' if dim else result.__str__()
+        self.logger.info(msg)
         return result
 
-    def get_volumes_count(self) -> int:
+    def get_volumes_count(self, skip_cd_rom: bool = False) -> int:
         """Count initialized volumes.
 
         Note: CD-ROMs and System Reserved volumes included.
 
+        :param skip_cd_rom: Skip CD-ROMs
         :return:
         """
 
-        return len(self.get_volumes())
+        result = self.get_volumes()
+        if skip_cd_rom:
+            return len([volume for volume in result if volume['DriveType'] != 'CD-ROM'])
+        return len(result)
+
+    @staticmethod
+    def _convert_b_to_mb(bytes_) -> int:
+        """Convert bytes to Megabytes with round up"""
+
+        result = bytes_ / 1024 / 1024
+        return round(result)
+
+    @staticmethod
+    def _convert_b_to_gb(bytes_) -> int:
+        """Convert bytes to Gigabytes with round up"""
+
+        result = bytes_ / 1024 / 1024 / 1024
+        return round(result)
 
     # ---------------- NEED REFACTORING ------------------
     def attach_share(self, share, username, password):
